Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(250)

Unified Diff: client/simple_string_dictionary_test.cc

Issue 656703002: Convert NULL to nullptr (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: Fix 80-column violations Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « client/simple_string_dictionary.h ('k') | compat/mac/mach-o/getsect.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: client/simple_string_dictionary_test.cc
diff --git a/client/simple_string_dictionary_test.cc b/client/simple_string_dictionary_test.cc
index a55b5a31f16c911a74d1745992ab59e79970006e..7cc298f9b6fc05a2f41bcb64aab0c5852b26e463 100644
--- a/client/simple_string_dictionary_test.cc
+++ b/client/simple_string_dictionary_test.cc
@@ -71,8 +71,8 @@ TEST(SimpleStringDictionary, SimpleStringDictionary) {
// Now make sure it's not there anymore
EXPECT_FALSE(dict.GetValueForKey("key3"));
- // Remove by setting value to NULL
- dict.SetKeyValue("key2", NULL);
+ // Remove by setting value to nullptr
+ dict.SetKeyValue("key2", nullptr);
// Now make sure it's not there anymore
EXPECT_FALSE(dict.GetValueForKey("key2"));
@@ -279,13 +279,13 @@ TEST(SimpleStringDictionary, OutOfSpace) {
TEST(SimpleStringDictionaryDeathTest, NullKey) {
TSimpleStringDictionary<4, 6, 6> map;
- ASSERT_DEATH(map.SetKeyValue(NULL, "hello"), "key");
+ ASSERT_DEATH(map.SetKeyValue(nullptr, "hello"), "key");
map.SetKeyValue("hi", "there");
- ASSERT_DEATH(map.GetValueForKey(NULL), "key");
+ ASSERT_DEATH(map.GetValueForKey(nullptr), "key");
EXPECT_STREQ("there", map.GetValueForKey("hi"));
- ASSERT_DEATH(map.GetValueForKey(NULL), "key");
+ ASSERT_DEATH(map.GetValueForKey(nullptr), "key");
map.RemoveKey("hi");
EXPECT_EQ(0u, map.GetCount());
}
« no previous file with comments | « client/simple_string_dictionary.h ('k') | compat/mac/mach-o/getsect.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698